package com.archeus.dex.html;


import java.io.FileReader;
import java.util.ArrayList;

import org.apache.xerces.dom.TextImpl;
import org.cyberneko.html.parsers.DOMParser;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;

import com.archeus.FormatedText;
import com.archeus.FormatedTextHelper;
import com.archeus.FormatedWord;
import com.archeus.FormatedWordList;
import com.archeus.TextAttr;

/**
 * <p>Imparte un text html in entitati cu format continuu. 
 *  Acestea se retin intr-o lista de <code>FormatedText</code></p>
 * @author ionut
 * @since Feb 24, 2007 1:10:43 PM
 */
public class HtmlParser {

    //
    // MAIN
    //

    /** Main. */
    public static void main(String[] args) throws Exception {
    	String fileName = args[0];
    	InputSource src = new InputSource(new FileReader(fileName));
    	src.setEncoding("UTF-8");
    	ArrayList<FormatedText> list = parseFile(src);
//    	for (FormatedText text : list) {
//			System.out.println(text);
//		}
    	FormatedWordList words = FormatedTextHelper.wordList(list);
    	for (FormatedWord word : words) {
//			System.out.print(word);
			System.out.println(word);
		}
    }
    public static ArrayList<FormatedText> parseFile(InputSource src) throws Exception {
    	ArrayList<FormatedText> res = new ArrayList<FormatedText>();
    	DOMParser parser = new DOMParser();
    	parser.parse(src);
    	parse(parser.getDocument(), 0, res);
    	return res;
    }
    
    /**
     * <p>Determina formatul unui nod parcurgand nodurile pana la radacina</p>
     * @author ionut
     * @since Feb 24, 2007 1:50:09 PM
     * @param node
     * @param fmt
     */
    public static void getFormat(Node node, TextAttr fmt) {
    	if (node == null)
    		return;
    	
    	if (node.getClass().getName().equals(org.apache.html.dom.HTMLElementImpl.class.getName())) {
    		String s = node.getNodeName().toUpperCase();
    		if (s.equals("B"))
    			fmt.setBold(true);
    		if (s.equals("I"))
    			fmt.setItalic(true);
    		
    	} // if class
    	getFormat(node.getParentNode(), fmt);    			
    }

    /**
     * <p>Cumuleaza in <code>list</code> portiuni de text cu aceeasi formatare </p> 
     * @author ionut
     * @since Feb 24, 2007 1:30:19 PM
     * @param node
     * @param level
     * @param list
     */
    public static void parse(Node node, int level, ArrayList<FormatedText> list) {
    	if (node instanceof org.apache.xerces.dom.TextImpl) {
    		TextImpl t = (TextImpl)node;
    		TextAttr fmt = new TextAttr();
    		getFormat(node, fmt);
    		list.add(new FormatedText(t.getTextContent(), fmt, level));
    	}
    	else {
    		if (node instanceof org.apache.html.dom.HTMLParagraphElementImpl)
//    			list.add(new FormatedText("<p></p>", new TextAttr(), level));
    			list.add(new FormatedText("\n", new TextAttr(), level));
    	}
    	
        Node child = node.getFirstChild();
        while (child != null) {
            parse(child, level, list);
            child = child.getNextSibling();
        }
    } 

} 
